@@ -1,8 +1,11 @@
 from camel_model.CamelModel import CamelModel
 
+from sql_models.shared.image.ImageFile import ImageFile
+from sql_models.shared.text.TextLine import TextLine
+
 
 class SmartKeyFault(CamelModel):
     fault_kind: list[TextLine]
-    flash_pattern_image: NewImageData | None
+    flash_pattern_image: ImageFile | None
     flashs_number_by_time: str | None
-    parts_to_review: list[TextLine] | None
\ No newline at end of file
+    parts_to_review: list[TextLine] | None
