@@ -1,9 +1,10 @@
 from sqlmodel import Field
 
+from sql_models.SQLCamelModel import SQLCamelModel
 from sql_models.shared.role.Role import Role
 
 
-class RoleVisibility:
+class RoleVisibility(SQLCamelModel):
     visibility: Role | None = Field(default=False)
 
 
